<?php

namespace PFAdviceServer;

/**
 * Carga de la clase generica para soporte a clientes SOAP WS-Secure
 */

const unbounded = 'unbounded';

class SoapObject
{
	/**
	 * Convierte un array en un arbol de objetos
	 *
	 * @access	protected
	 * @param  	array		$array	Array a convertir
	 * @return	\stdClass	Devuelve el objeto equivalente
	*/
	protected function array2ObjectTree($array)
	{
		if (is_numeric(key($array)))
		{
			foreach ($array as $key => $value)
			{
				$array[$key] = $this->array_to_objecttree($value);
			}
			return $array;
		}
		$Object = new \stdClass;
		foreach ($array as $key => $value)
		{
			if (is_array($value))
			{
				$Object->$key = $this->array_to_objecttree($value);
			}
			else
			{
				$Object->$key = $value;
			}
		}
		return $Object;
	}//Fin array2ObjectTree

	/**
	 * Convierte un objeto en un array asociativo
	 *
	 * @access	private
	 * @param  	array		$array	Array a convertir
	 * @return	\stdClass	Devuelve el objeto equivalente
	 */
	protected function objectTree2array($obj)
	{
		if (is_array($obj) || is_object($obj))
		{
			$result = array();
			foreach ($obj as $key => $value)
			{
				$result[$key] = $this->objectTree2array($value);
			}
			return $result;
		}
		return $obj;
	}//Fin objectTree2array


	private function __anyType_SoapVar($childData, $fieldName, $namespace) {
//var_dump($childData);
		if (is_a($childData, 'DateTime')) {
//var_dump($childData);
//die('DateTime: ' . $fieldName);
			return new \SoapVar($childData->format(\DateTime::ATOM), XSD_DATETIME, 'dateTime', 'http://www.w3.org/2001/XMLSchema', $fieldName, $namespace);
		} elseif (is_int($childData)) {
//die('Integer: ' . $fieldName);
			return new \SoapVar($childData, XSD_INTEGER, null, null, $fieldName, $namespace);
		}

//die('Generic: ' . $fieldName);
		return new \SoapVar($childData, XSD_STRING, 'string', 'http://www.w3.org/2001/XMLSchema', $fieldName, $namespace);
	}

	private function __basic_SoapVar($childData, $basicType, $fieldName, $namespace) {
		switch ($basicType) {
			case XSD_DATETIME:
				return new \SoapVar($childData->format(\DateTime::ATOM), $basicType, null, null, $fieldName, $namespace);

			default:
				return new \SoapVar($childData, $basicType, null, null, $fieldName, $namespace);
		}
	}

	public function __doChild($parentTag, $value, $fieldName, $type, $namespace, $minOccurs, $maxOccurs)
	{
		//echo("__doChild: $type [$fieldName]<br>");
		$fieldSet = isset($value);
		if (!$fieldSet) {
			if ($minOccurs > 0) {
				throw new \Exception("No se ha encontrado el subcampo obligatorio '" . $fieldName . '"');
			} else {
				return true;
			}
		}

		$vChildData = $value;
		if ($maxOccurs == 1) {
			$vChildData = array( $value );
		} else {
			if ($maxOccurs != 'unbounded') {
				if ($maxOccurs > sizeof($vChildData)) {
					throw new \Exception("El campo '" . $fieldName . '" no tiene tantas ocurrencias como se esperaban');
				}
			} else {
//				var_dump($vChildData);die;
			}
		}

//var_dump(array_keys($vChildData));
		for ($iIter=0; $iIter < sizeof($vChildData); $iIter++) {
			$childData = $vChildData[$iIter];

			if ((($minOccurs > 0) && $fieldSet) || $fieldSet) {
				if (is_int($type) && $type != SOAP_ENC_OBJECT) {

					$basicType = $type;
//echo("Basic: $type | $basicType [$fieldName]<br>");
					if ($basicType !== XSD_ANYTYPE) {
						$childSOAP = $this->__basic_SoapVar($childData, $basicType, $fieldName, $namespace);
					} else {
						$childSOAP = $this->__anyType_SoapVar($childData, $fieldName, $namespace);
					}
					$parentTag->append( $childSOAP );
//					return true;

				} else { //if (isset($this->$funcName)) {
					$childSOAP = $childData->toSoap($fieldName, $namespace);
					$parentTag->append( $childSOAP );
//					return true;
				}
			} else {
				return false;
			}

		}

		// TODO: HACER EL MULTIAPARICION!!!
		/*
		var_dump($parentTag);
		var_dump($vData);
		var_dump($fieldName);
		var_dump($type);
		var_dump($namespace);
		var_dump($minOccurs);
		var_dump($maxOccurs);

		die("FAIL!!!");
		*/

		return true;
	}



	static public function is_assoc($array) {
		foreach(array_keys($array) as $key) {
			if (!is_int($key)) return true;
		}
		return false;
	}

	static public function endsWith($haystack, $needle) {
		// search forward starting from end minus needle length characters
		return $needle === "" || (($temp = strlen($haystack) - strlen($needle)) >= 0 && strpos($haystack, $needle, $temp) !== false);
	}
}

























class documentType extends SoapObject {
	// name="identifier" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_identifier = null;
	private $_hasIdentifier = false;
	public function setIdentifier($value) {
		$this->_identifier = $value;
		$this->_hasIdentifier = ($value !== null);
	}
	public function hasIdentifier() {
		return $this->_hasIdentifier;
	}
	public function getIdentifier() {
		return $this->_identifier;
	}

	// name="description" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_description = null;
	private $_hasDescription = false;
	public function setDescription($value) {
		$this->_description = $value;
		$this->_hasDescription = ($value !== null);
	}
	public function hasDescription() {
		return $this->_hasDescription;
	}
	public function getDescription() {
		return $this->_description;
	}

	// name="valid" type="xsd:boolean"[102] minOccurs="0" maxOccurs="1" nillable="true"
	private $_valid = null;
	private $_hasValid = false;
	public function setValid($value) {
		$this->_valid = $value;
		$this->_hasValid = ($value !== null);
	}
	public function hasValid() {
		return $this->_hasValid;
	}
	public function getValid() {
		return $this->_valid;
	}


	static public function fromSoap($vData) {
		$newItem = new documentType();
		if (isset($vData['identifier'])) {
			$newItem->setIdentifier($vData['identifier']);
		}
		if (isset($vData['description'])) {
			$newItem->setDescription($vData['description']);
		}
		if (isset($vData['valid'])) {
			$newItem->setValid($vData['valid']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_identifier, 'identifier', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_description, 'description', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_valid, 'valid', 102, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class documentTypeList extends SoapObject {
	// name="documentType" type="type:documentType"[COMPLEXTYPE] minOccurs="0" maxOccurs="unbounded" nillable="false"
	private $_documentType = array();
	private $_hasDocumentType = false;
	public function replaceArrayDocumentType($value) {
		$this->_documentType = $value;
		$this->_hasDocumentType = (isset($this->_documentType) && !empty($this->_documentType));
	}
	public function retrieveArrayDocumentType() {
		return $this->_documentType;
	}
	public function addDocumentType($value) {
		array_push($this->_documentType, $value);
		$this->_hasDocumentType = (isset($this->_documentType) && !empty($this->_documentType));
	}
	public function hasDocumentType() {
		return $this->_hasDocumentType;
	}
	public function getDocumentType($index) {
		return $this->_documentType[$index];
	}
	public function countDocumentType() {
		return count($this->_documentType);
	}


	static public function fromSoap($vData) {
		$newItem = new documentTypeList();
		if (isset($vData['documentType']) && !empty($vData['documentType'])) {
			if (SoapObject::is_assoc($vData['documentType'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = documentType::fromSoap($vData['documentType']);
				$newItem->addDocumentType($newClass);
			} else {
				foreach ($vData['documentType'] as $oVar) {
					$newClass = documentType::fromSoap($oVar);
					$newItem->addDocumentType($newClass);
				}
			}
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_documentType, 'documentType', SOAP_ENC_OBJECT, $namespace, 0, unbounded);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class importanceLevel extends SoapObject {
	// name="levelCode" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_levelCode = null;
	private $_hasLevelCode = false;
	public function setLevelCode($value) {
		$this->_levelCode = $value;
		$this->_hasLevelCode = ($value !== null);
	}
	public function hasLevelCode() {
		return $this->_hasLevelCode;
	}
	public function getLevelCode() {
		return $this->_levelCode;
	}

	// name="description" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_description = null;
	private $_hasDescription = false;
	public function setDescription($value) {
		$this->_description = $value;
		$this->_hasDescription = ($value !== null);
	}
	public function hasDescription() {
		return $this->_hasDescription;
	}
	public function getDescription() {
		return $this->_description;
	}


	static public function fromSoap($vData) {
		$newItem = new importanceLevel();
		if (isset($vData['levelCode'])) {
			$newItem->setLevelCode($vData['levelCode']);
		}
		if (isset($vData['description'])) {
			$newItem->setDescription($vData['description']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_levelCode, 'levelCode', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_description, 'description', 101, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class importanceLevelList extends SoapObject {
	// name="importanceLevels" type="type:importanceLevel"[COMPLEXTYPE] minOccurs="0" maxOccurs="unbounded" nillable="false"
	private $_importanceLevels = array();
	private $_hasImportanceLevels = false;
	public function replaceArrayImportanceLevels($value) {
		$this->_importanceLevels = $value;
		$this->_hasImportanceLevels = (isset($this->_importanceLevels) && !empty($this->_importanceLevels));
	}
	public function retrieveArrayImportanceLevels() {
		return $this->_importanceLevels;
	}
	public function addImportanceLevels($value) {
		array_push($this->_importanceLevels, $value);
		$this->_hasImportanceLevels = (isset($this->_importanceLevels) && !empty($this->_importanceLevels));
	}
	public function hasImportanceLevels() {
		return $this->_hasImportanceLevels;
	}
	public function getImportanceLevels($index) {
		return $this->_importanceLevels[$index];
	}
	public function countImportanceLevels() {
		return count($this->_importanceLevels);
	}


	static public function fromSoap($vData) {
		$newItem = new importanceLevelList();
		if (isset($vData['importanceLevels']) && !empty($vData['importanceLevels'])) {
			if (SoapObject::is_assoc($vData['importanceLevels'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
//PABLO: REVIEW: Sobra una S o falta un LSIT??
				$newClass = importanceLevel::fromSoap($vData['importanceLevels']);
				$newItem->addImportanceLevels($newClass);
			} else {
				foreach ($vData['importanceLevels'] as $oVar) {
					$newClass = importanceLevel::fromSoap($oVar);
					$newItem->addImportanceLevels($newClass);
				}
			}
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_importanceLevels, 'importanceLevels', SOAP_ENC_OBJECT, $namespace, 0, unbounded);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class state extends SoapObject {
	// name="identifier" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_identifier = null;
	private $_hasIdentifier = false;
	public function setIdentifier($value) {
		$this->_identifier = $value;
		$this->_hasIdentifier = ($value !== null);
	}
	public function hasIdentifier() {
		return $this->_hasIdentifier;
	}
	public function getIdentifier() {
		return $this->_identifier;
	}


	static public function fromSoap($vData) {
		$newItem = new state();
		if (isset($vData['identifier'])) {
			$newItem->setIdentifier($vData['identifier']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_identifier, 'identifier', 101, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class stateList extends SoapObject {
	// name="state" type="type:state"[COMPLEXTYPE] minOccurs="0" maxOccurs="unbounded" nillable="false"
	private $_state = array();
	private $_hasState = false;
	public function replaceArrayState($value) {
		$this->_state = $value;
		$this->_hasState = (isset($this->_state) && !empty($this->_state));
	}
	public function retrieveArrayState() {
		return $this->_state;
	}
	public function addState($value) {
		array_push($this->_state, $value);
		$this->_hasState = (isset($this->_state) && !empty($this->_state));
	}
	public function hasState() {
		return $this->_hasState;
	}
	public function getState($index) {
		return $this->_state[$index];
	}
	public function countState() {
		return count($this->_state);
	}


	static public function fromSoap($vData) {
		$newItem = new stateList();
		if (isset($vData['state']) && !empty($vData['state'])) {
			if (SoapObject::is_assoc($vData['state'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = state::fromSoap($vData['state']);
				$newItem->addState($newClass);
			} else {
				foreach ($vData['state'] as $oVar) {
					$newClass = state::fromSoap($oVar);
					$newItem->addState($newClass);
				}
			}
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_state, 'state', SOAP_ENC_OBJECT, $namespace, 0, unbounded);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class userJob extends SoapObject {
	// name="identifier" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_identifier = null;
	private $_hasIdentifier = false;
	public function setIdentifier($value) {
		$this->_identifier = $value;
		$this->_hasIdentifier = ($value !== null);
	}
	public function hasIdentifier() {
		return $this->_hasIdentifier;
	}
	public function getIdentifier() {
		return $this->_identifier;
	}

	function __construct() {
		throw new \Exception('La clase userJob no debe utilizarse directamente. Debe instanciarse en su lugar "user" o "job"');
	}

	static public function fromSoap($vData) {
		$isUser = null;
		if (isset($vData['@attributes']) && isset($vData['@attributes']['type'])) {
			if (SoapObject::endsWith($vData['@attributes']['type'], ':user')) {
				$isUser = true;
			} elseif (SoapObject::endsWith($vData['@attributes']['type'], ':job')) {
				$isUser = false;
			}
		} elseif (isset($vData['name'])) {
			$isUser = true;
		} elseif (isset($vData['description'])) {
			$isUser = false;
		}

		if (is_null($isUser)) {
			error_log (__FILE__.__LINE__.'::'.print_r($vData, true));
			throw new \Exception('No se ha podido determinar la subclase de userJob. No se ha encontrado "@attributes", "name" ni "description" para poder clasificarlo');
		}

		if ($isUser) {
			return user::fromSoap($vData);
		} else {
			return job::fromSoap($vData);
		}

		return null;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_identifier, 'identifier', 101, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class user extends SoapObject {
	// name="identifier" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_identifier = null;
	private $_hasIdentifier = false;
	public function setIdentifier($value) {
		$this->_identifier = $value;
		$this->_hasIdentifier = ($value !== null);
	}
	public function hasIdentifier() {
		return $this->_hasIdentifier;
	}
	public function getIdentifier() {
		return $this->_identifier;
	}

	// name="name" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_name = null;
	private $_hasName = false;
	public function setName($value) {
		$this->_name = $value;
		$this->_hasName = ($value !== null);
	}
	public function hasName() {
		return $this->_hasName;
	}
	public function getName() {
		return $this->_name;
	}

	// name="surname1" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_surname1 = null;
	private $_hasSurname1 = false;
	public function setSurname1($value) {
		$this->_surname1 = $value;
		$this->_hasSurname1 = ($value !== null);
	}
	public function hasSurname1() {
		return $this->_hasSurname1;
	}
	public function getSurname1() {
		return $this->_surname1;
	}

	// name="surname2" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_surname2 = null;
	private $_hasSurname2 = false;
	public function setSurname2($value) {
		$this->_surname2 = $value;
		$this->_hasSurname2 = ($value !== null);
	}
	public function hasSurname2() {
		return $this->_hasSurname2;
	}
	public function getSurname2() {
		return $this->_surname2;
	}


	static public function fromSoap($vData) {
		$newItem = new user();
		if (isset($vData['identifier'])) {
			$newItem->setIdentifier($vData['identifier']);
		}
		if (isset($vData['name'])) {
			$newItem->setName($vData['name']);
		}
		if (isset($vData['surname1'])) {
			$newItem->setSurname1($vData['surname1']);
		}
		if (isset($vData['surname2'])) {
			$newItem->setSurname2($vData['surname2']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$vData = array();
		$vData['identifier'] = $this->_identifier;
		if (sizeof($this->_name) > 0) {
			$vData['name'] = $this->_name;
		}
		if (sizeof($this->_surname1) > 0) {
			$vData['surname1'] = $this->_surname1;
		}
		if (sizeof($this->_surname2) > 0) {
			$vData['surname2'] = $this->_surname2;
		}

		return new \SoapVar($vData, SOAP_ENC_OBJECT, 'user', 'urn:juntadeandalucia:cice:pfirma:advice:request:v2.0', $fieldName, $namespace);

		/*
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_identifier, 'identifier', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_name, 'name', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_surname1, 'surname1', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_surname2, 'surname2', 101, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
		*/
	}
}

class job extends SoapObject {
	// name="identifier" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_identifier = null;
	private $_hasIdentifier = false;
	public function setIdentifier($value) {
		$this->_identifier = $value;
		$this->_hasIdentifier = ($value !== null);
	}
	public function hasIdentifier() {
		return $this->_hasIdentifier;
	}
	public function getIdentifier() {
		return $this->_identifier;
	}

	// name="description" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_description = null;
	private $_hasDescription = false;
	public function setDescription($value) {
		$this->_description = $value;
		$this->_hasDescription = ($value !== null);
	}
	public function hasDescription() {
		return $this->_hasDescription;
	}
	public function getDescription() {
		return $this->_description;
	}


	static public function fromSoap($vData) {
		$newItem = new job();
		if (isset($vData['identifier'])) {
			$newItem->setIdentifier($vData['identifier']);
		}
		if (isset($vData['description'])) {
			$newItem->setDescription($vData['description']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$vData = array();
		$vData['identifier'] = $this->_identifier;
		if (sizeof($this->_description) > 0) {
			$vData['description'] = $this->_description;
		}

		return new \SoapVar($vData, SOAP_ENC_OBJECT, 'job', 'urn:juntadeandalucia:cice:pfirma:advice:request:v2.0', $fieldName, $namespace);

		/*
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_identifier, 'identifier', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_description, 'description', 101, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
		*/
	}
}

class jobList extends SoapObject {
	// name="job" type="type:job"[COMPLEXTYPE] minOccurs="0" maxOccurs="unbounded" nillable="false"
	private $_job = array();
	private $_hasJob = false;
	public function replaceArrayJob($value) {
		$this->_job = $value;
		$this->_hasJob = (isset($this->_job) && !empty($this->_job));
	}
	public function retrieveArrayJob() {
		return $this->_job;
	}
	public function addJob($value) {
		array_push($this->_job, $value);
		$this->_hasJob = (isset($this->_job) && !empty($this->_job));
	}
	public function hasJob() {
		return $this->_hasJob;
	}
	public function getJob($index) {
		return $this->_job[$index];
	}
	public function countJob() {
		return count($this->_job);
	}


	static public function fromSoap($vData) {
		$newItem = new jobList();
		if (isset($vData['job']) && !empty($vData['job'])) {
			if (SoapObject::is_assoc($vData['job'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = job::fromSoap($vData['job']);
				$newItem->addJob($newClass);
			} else {
				foreach ($vData['job'] as $oVar) {
					$newClass = job::fromSoap($oVar);
					$newItem->addJob($newClass);
				}
			}
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_job, 'job', SOAP_ENC_OBJECT, $namespace, 0, unbounded);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class userList extends SoapObject {
	// name="user" type="type:user"[COMPLEXTYPE] minOccurs="0" maxOccurs="unbounded" nillable="false"
	private $_user = array();
	private $_hasUser = false;
	public function replaceArrayUser($value) {
		$this->_user = $value;
		$this->_hasUser = (isset($this->_user) && !empty($this->_user));
	}
	public function retrieveArrayUser() {
		return $this->_user;
	}
	public function addUser($value) {
		array_push($this->_user, $value);
		$this->_hasUser = (isset($this->_user) && !empty($this->_user));
	}
	public function hasUser() {
		return $this->_hasUser;
	}
	public function getUser($index) {
		return $this->_user[$index];
	}
	public function countUser() {
		return count($this->_user);
	}


	static public function fromSoap($vData) {
		$newItem = new userList();
		if (isset($vData['user']) && !empty($vData['user'])) {
			if (SoapObject::is_assoc($vData['user'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = user::fromSoap($vData['user']);
				$newItem->addUser($newClass);
			} else {
				foreach ($vData['user'] as $oVar) {
					$newClass = user::fromSoap($oVar);
					$newItem->addUser($newClass);
				}
			}
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_user, 'user', SOAP_ENC_OBJECT, $namespace, 0, unbounded);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class seat extends SoapObject {
	// name="code" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_code = null;
	private $_hasCode = false;
	public function setCode($value) {
		$this->_code = $value;
		$this->_hasCode = ($value !== null);
	}
	public function hasCode() {
		return $this->_hasCode;
	}
	public function getCode() {
		return $this->_code;
	}

	// name="description" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_description = null;
	private $_hasDescription = false;
	public function setDescription($value) {
		$this->_description = $value;
		$this->_hasDescription = ($value !== null);
	}
	public function hasDescription() {
		return $this->_hasDescription;
	}
	public function getDescription() {
		return $this->_description;
	}


	static public function fromSoap($vData) {
		$newItem = new seat();
		if (isset($vData['code'])) {
			$newItem->setCode($vData['code']);
		}
		if (isset($vData['description'])) {
			$newItem->setDescription($vData['description']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_code, 'code', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_description, 'description', 101, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class seatList extends SoapObject {
	// name="seat" type="type:seat"[COMPLEXTYPE] minOccurs="0" maxOccurs="unbounded" nillable="false"
	private $_seat = array();
	private $_hasSeat = false;
	public function replaceArraySeat($value) {
		$this->_seat = $value;
		$this->_hasSeat = (isset($this->_seat) && !empty($this->_seat));
	}
	public function retrieveArraySeat() {
		return $this->_seat;
	}
	public function addSeat($value) {
		array_push($this->_seat, $value);
		$this->_hasSeat = (isset($this->_seat) && !empty($this->_seat));
	}
	public function hasSeat() {
		return $this->_hasSeat;
	}
	public function getSeat($index) {
		return $this->_seat[$index];
	}
	public function countSeat() {
		return count($this->_seat);
	}


	static public function fromSoap($vData) {
		$newItem = new seatList();
		if (isset($vData['seat']) && !empty($vData['seat'])) {
			if (SoapObject::is_assoc($vData['seat'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = seat::fromSoap($vData['seat']);
				$newItem->addSeat($newClass);
			} else {
				foreach ($vData['seat'] as $oVar) {
					$newClass = seat::fromSoap($oVar);
					$newItem->addSeat($newClass);
				}
			}
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_seat, 'seat', SOAP_ENC_OBJECT, $namespace, 0, unbounded);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class enhancedUserJobInfo extends SoapObject {
	// name="seat" type="type:seat"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="true"
	private $_seat = null;
	private $_hasSeat = false;
	public function setSeat($value) {
		$this->_seat = $value;
		$this->_hasSeat = ($value !== null);
	}
	public function hasSeat() {
		return $this->_hasSeat;
	}
	public function getSeat() {
		return $this->_seat;
	}

	// name="valid" type="xsd:boolean"[102] minOccurs="0" maxOccurs="1" nillable="true"
	private $_valid = null;
	private $_hasValid = false;
	public function setValid($value) {
		$this->_valid = $value;
		$this->_hasValid = ($value !== null);
	}
	public function hasValid() {
		return $this->_hasValid;
	}
	public function getValid() {
		return $this->_valid;
	}

	// name="visibleOtherSeats" type="xsd:boolean"[102] minOccurs="0" maxOccurs="1" nillable="true"
	private $_visibleOtherSeats = null;
	private $_hasVisibleOtherSeats = false;
	public function setVisibleOtherSeats($value) {
		$this->_visibleOtherSeats = $value;
		$this->_hasVisibleOtherSeats = ($value !== null);
	}
	public function hasVisibleOtherSeats() {
		return $this->_hasVisibleOtherSeats;
	}
	public function getVisibleOtherSeats() {
		return $this->_visibleOtherSeats;
	}

	// name="parameterList" type="type:parameterList"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="true"
	private $_parameterList = null;
	private $_hasParameterList = false;
	public function setParameterList($value) {
		$this->_parameterList = $value;
		$this->_hasParameterList = ($value !== null);
	}
	public function hasParameterList() {
		return $this->_hasParameterList;
	}
	public function getParameterList() {
		return $this->_parameterList;
	}


	static public function fromSoap($vData) {
		$newItem = new enhancedUserJobInfo();
		if (isset($vData['seat'])) {
			$newClass = seat::fromSoap($vData['seat']);
			$newItem->setSeat($newClass);
		}
							if (isset($vData['valid'])) {
			$newItem->setValid($vData['valid']);
		}
		if (isset($vData['visibleOtherSeats'])) {
			$newItem->setVisibleOtherSeats($vData['visibleOtherSeats']);
		}
		if (isset($vData['parameterList'])) {
			$newClass = parameterList::fromSoap($vData['parameterList']);
			$newItem->setParameterList($newClass);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_seat, 'seat', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_valid, 'valid', 102, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_visibleOtherSeats, 'visibleOtherSeats', 102, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_parameterList, 'parameterList', SOAP_ENC_OBJECT, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class enhancedUser extends SoapObject {
	// name="user" type="type:user"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="true"
	private $_user = null;
	private $_hasUser = false;
	public function setUser($value) {
		$this->_user = $value;
		$this->_hasUser = ($value !== null);
	}
	public function hasUser() {
		return $this->_hasUser;
	}
	public function getUser() {
		return $this->_user;
	}

	// name="enhancedUserJobInfo" type="type:enhancedUserJobInfo"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="true"
	private $_enhancedUserJobInfo = null;
	private $_hasEnhancedUserJobInfo = false;
	public function setEnhancedUserJobInfo($value) {
		$this->_enhancedUserJobInfo = $value;
		$this->_hasEnhancedUserJobInfo = ($value !== null);
	}
	public function hasEnhancedUserJobInfo() {
		return $this->_hasEnhancedUserJobInfo;
	}
	public function getEnhancedUserJobInfo() {
		return $this->_enhancedUserJobInfo;
	}


	static public function fromSoap($vData) {
		$newItem = new enhancedUser();
		if (isset($vData['user'])) {
			$newClass = user::fromSoap($vData['user']);
			$newItem->setUser($newClass);
		}
							if (isset($vData['enhancedUserJobInfo'])) {
			$newClass = enhancedUserJobInfo::fromSoap($vData['enhancedUserJobInfo']);
			$newItem->setEnhancedUserJobInfo($newClass);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_user, 'user', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_enhancedUserJobInfo, 'enhancedUserJobInfo', SOAP_ENC_OBJECT, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class enhancedJob extends SoapObject {
	// name="job" type="type:job"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="true"
	private $_job = null;
	private $_hasJob = false;
	public function setJob($value) {
		$this->_job = $value;
		$this->_hasJob = ($value !== null);
	}
	public function hasJob() {
		return $this->_hasJob;
	}
	public function getJob() {
		return $this->_job;
	}

	// name="enhancedUserJobInfo" type="type:enhancedUserJobInfo"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="true"
	private $_enhancedUserJobInfo = null;
	private $_hasEnhancedUserJobInfo = false;
	public function setEnhancedUserJobInfo($value) {
		$this->_enhancedUserJobInfo = $value;
		$this->_hasEnhancedUserJobInfo = ($value !== null);
	}
	public function hasEnhancedUserJobInfo() {
		return $this->_hasEnhancedUserJobInfo;
	}
	public function getEnhancedUserJobInfo() {
		return $this->_enhancedUserJobInfo;
	}


	static public function fromSoap($vData) {
		$newItem = new enhancedJob();
		if (isset($vData['job'])) {
			$newClass = job::fromSoap($vData['job']);
			$newItem->setJob($newClass);
		}
							if (isset($vData['enhancedUserJobInfo'])) {
			$newClass = enhancedUserJobInfo::fromSoap($vData['enhancedUserJobInfo']);
			$newItem->setEnhancedUserJobInfo($newClass);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_job, 'job', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_enhancedUserJobInfo, 'enhancedUserJobInfo', SOAP_ENC_OBJECT, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class enhancedUserList extends SoapObject {
	// name="enhancedUser" type="type:enhancedUser"[COMPLEXTYPE] minOccurs="0" maxOccurs="unbounded" nillable="false"
	private $_enhancedUser = array();
	private $_hasEnhancedUser = false;
	public function replaceArrayEnhancedUser($value) {
		$this->_enhancedUser = $value;
		$this->_hasEnhancedUser = (isset($this->_enhancedUser) && !empty($this->_enhancedUser));
	}
	public function retrieveArrayEnhancedUser() {
		return $this->_enhancedUser;
	}
	public function addEnhancedUser($value) {
		array_push($this->_enhancedUser, $value);
		$this->_hasEnhancedUser = (isset($this->_enhancedUser) && !empty($this->_enhancedUser));
	}
	public function hasEnhancedUser() {
		return $this->_hasEnhancedUser;
	}
	public function getEnhancedUser($index) {
		return $this->_enhancedUser[$index];
	}
	public function countEnhancedUser() {
		return count($this->_enhancedUser);
	}


	static public function fromSoap($vData) {
		$newItem = new enhancedUserList();
		if (isset($vData['enhancedUser']) && !empty($vData['enhancedUser'])) {
			if (SoapObject::is_assoc($vData['enhancedUser'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = enhancedUser::fromSoap($vData['enhancedUser']);
				$newItem->addEnhancedUser($newClass);
			} else {
				foreach ($vData['enhancedUser'] as $oVar) {
					$newClass = enhancedUser::fromSoap($oVar);
					$newItem->addEnhancedUser($newClass);
				}
			}
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_enhancedUser, 'enhancedUser', SOAP_ENC_OBJECT, $namespace, 0, unbounded);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class enhancedJobList extends SoapObject {
	// name="enhancedJob" type="type:enhancedJob"[COMPLEXTYPE] minOccurs="0" maxOccurs="unbounded" nillable="false"
	private $_enhancedJob = array();
	private $_hasEnhancedJob = false;
	public function replaceArrayEnhancedJob($value) {
		$this->_enhancedJob = $value;
		$this->_hasEnhancedJob = (isset($this->_enhancedJob) && !empty($this->_enhancedJob));
	}
	public function retrieveArrayEnhancedJob() {
		return $this->_enhancedJob;
	}
	public function addEnhancedJob($value) {
		array_push($this->_enhancedJob, $value);
		$this->_hasEnhancedJob = (isset($this->_enhancedJob) && !empty($this->_enhancedJob));
	}
	public function hasEnhancedJob() {
		return $this->_hasEnhancedJob;
	}
	public function getEnhancedJob($index) {
		return $this->_enhancedJob[$index];
	}
	public function countEnhancedJob() {
		return count($this->_enhancedJob);
	}


	static public function fromSoap($vData) {
		$newItem = new enhancedJobList();
		if (isset($vData['enhancedJob']) && !empty($vData['enhancedJob'])) {
			if (SoapObject::is_assoc($vData['enhancedJob'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = enhancedJob::fromSoap($vData['enhancedJob']);
				$newItem->addEnhancedJob($newClass);
			} else {
				foreach ($vData['enhancedJob'] as $oVar) {
					$newClass = enhancedJob::fromSoap($oVar);
					$newItem->addEnhancedJob($newClass);
				}
			}
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_enhancedJob, 'enhancedJob', SOAP_ENC_OBJECT, $namespace, 0, unbounded);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class enhancedUserJobAssociated extends SoapObject {
	// name="enhancedUser" type="type:enhancedUser"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
	private $_enhancedUser = null;
	private $_hasEnhancedUser = false;
	public function setEnhancedUser($value) {
		$this->_enhancedUser = $value;
		$this->_hasEnhancedUser = ($value !== null);
	}
	public function hasEnhancedUser() {
		return $this->_hasEnhancedUser;
	}
	public function getEnhancedUser() {
		return $this->_enhancedUser;
	}

	// name="enhancedJob" type="type:enhancedJob"[COMPLEXTYPE] minOccurs="1" maxOccurs="1" nillable="false"
	private $_enhancedJob = null;
	private $_hasEnhancedJob = false;
	public function setEnhancedJob($value) {
		$this->_enhancedJob = $value;
		$this->_hasEnhancedJob = ($value !== null);
	}
	public function hasEnhancedJob() {
		return $this->_hasEnhancedJob;
	}
	public function getEnhancedJob() {
		return $this->_enhancedJob;
	}

	// name="fstart" type="xsd:dateTime"[107] minOccurs="1" maxOccurs="1" nillable="false"
	private $_fstart = null;
	private $_hasFstart = false;
	public function setFstart($value) {
		$this->_fstart = $value;
		$this->_hasFstart = ($value !== null);
	}
	public function hasFstart() {
		return $this->_hasFstart;
	}
	public function getFstart() {
		return $this->_fstart;
	}

	// name="fend" type="xsd:dateTime"[107] minOccurs="0" maxOccurs="1" nillable="true"
	private $_fend = null;
	private $_hasFend = false;
	public function setFend($value) {
		$this->_fend = $value;
		$this->_hasFend = ($value !== null);
	}
	public function hasFend() {
		return $this->_hasFend;
	}
	public function getFend() {
		return $this->_fend;
	}


	static public function fromSoap($vData) {
		$newItem = new enhancedUserJobAssociated();
		if (!isset($vData['enhancedUser'])) {
			throw new \Exception('El parametro enhancedUser es obligatorio');
		}
		if (isset($vData['enhancedUser'])) {
			$newClass = enhancedUser::fromSoap($vData['enhancedUser']);
			$newItem->setEnhancedUser($newClass);
		}
							if (!isset($vData['enhancedJob'])) {
			throw new \Exception('El parametro enhancedJob es obligatorio');
		}
		if (isset($vData['enhancedJob'])) {
			$newClass = enhancedJob::fromSoap($vData['enhancedJob']);
			$newItem->setEnhancedJob($newClass);
		}
							if (!isset($vData['fstart'])) {
			throw new \Exception('El parametro fstart es obligatorio');
		}
		if (isset($vData['fstart'])) {
			$newItem->setFstart($vData['fstart']);
		}
		if (isset($vData['fend'])) {
			$newItem->setFend($vData['fend']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_enhancedUser, 'enhancedUser', SOAP_ENC_OBJECT, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_enhancedJob, 'enhancedJob', SOAP_ENC_OBJECT, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_fstart, 'fstart', 107, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_fend, 'fend', 107, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class enhancedUserJobAssociatedList extends SoapObject {
	// name="enhancedUserJobAssociated" type="type:enhancedUserJobAssociated"[COMPLEXTYPE] minOccurs="0" maxOccurs="unbounded" nillable="false"
	private $_enhancedUserJobAssociated = array();
	private $_hasEnhancedUserJobAssociated = false;
	public function replaceArrayEnhancedUserJobAssociated($value) {
		$this->_enhancedUserJobAssociated = $value;
		$this->_hasEnhancedUserJobAssociated = (isset($this->_enhancedUserJobAssociated) && !empty($this->_enhancedUserJobAssociated));
	}
	public function retrieveArrayEnhancedUserJobAssociated() {
		return $this->_enhancedUserJobAssociated;
	}
	public function addEnhancedUserJobAssociated($value) {
		array_push($this->_enhancedUserJobAssociated, $value);
		$this->_hasEnhancedUserJobAssociated = (isset($this->_enhancedUserJobAssociated) && !empty($this->_enhancedUserJobAssociated));
	}
	public function hasEnhancedUserJobAssociated() {
		return $this->_hasEnhancedUserJobAssociated;
	}
	public function getEnhancedUserJobAssociated($index) {
		return $this->_enhancedUserJobAssociated[$index];
	}
	public function countEnhancedUserJobAssociated() {
		return count($this->_enhancedUserJobAssociated);
	}


	static public function fromSoap($vData) {
		$newItem = new enhancedUserJobAssociatedList();
		if (isset($vData['enhancedUserJobAssociated']) && !empty($vData['enhancedUserJobAssociated'])) {
			if (SoapObject::is_assoc($vData['enhancedUserJobAssociated'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = enhancedUserJobAssociated::fromSoap($vData['enhancedUserJobAssociated']);
				$newItem->addEnhancedUserJobAssociated($newClass);
			} else {
				foreach ($vData['enhancedUserJobAssociated'] as $oVar) {
					$newClass = enhancedUserJobAssociated::fromSoap($oVar);
					$newItem->addEnhancedUserJobAssociated($newClass);
				}
			}
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_enhancedUserJobAssociated, 'enhancedUserJobAssociated', SOAP_ENC_OBJECT, $namespace, 0, unbounded);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class parameter extends SoapObject {
	// name="identifier" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_identifier = null;
	private $_hasIdentifier = false;
	public function setIdentifier($value) {
		$this->_identifier = $value;
		$this->_hasIdentifier = ($value !== null);
	}
	public function hasIdentifier() {
		return $this->_hasIdentifier;
	}
	public function getIdentifier() {
		return $this->_identifier;
	}

	// name="value" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_value = null;
	private $_hasValue = false;
	public function setValue($value) {
		$this->_value = $value;
		$this->_hasValue = ($value !== null);
	}
	public function hasValue() {
		return $this->_hasValue;
	}
	public function getValue() {
		return $this->_value;
	}


	static public function fromSoap($vData) {
		$newItem = new parameter();
		if (isset($vData['identifier'])) {
			$newItem->setIdentifier($vData['identifier']);
		}
		if (isset($vData['value'])) {
			$newItem->setValue($vData['value']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_identifier, 'identifier', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_value, 'value', 101, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class request extends SoapObject {
	// name="identifier" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_identifier = null;
	private $_hasIdentifier = false;
	public function setIdentifier($value) {
		$this->_identifier = $value;
		$this->_hasIdentifier = ($value !== null);
	}
	public function hasIdentifier() {
		return $this->_hasIdentifier;
	}
	public function getIdentifier() {
		return $this->_identifier;
	}

	// name="subject" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_subject = null;
	private $_hasSubject = false;
	public function setSubject($value) {
		$this->_subject = $value;
		$this->_hasSubject = ($value !== null);
	}
	public function hasSubject() {
		return $this->_hasSubject;
	}
	public function getSubject() {
		return $this->_subject;
	}

	// name="fentry" type="xsd:dateTime"[107] minOccurs="0" maxOccurs="1" nillable="false"
	private $_fentry = null;
	private $_hasFentry = false;
	public function setFentry($value) {
		$this->_fentry = $value;
		$this->_hasFentry = ($value !== null);
	}
	public function hasFentry() {
		return $this->_hasFentry;
	}
	public function getFentry() {
		return $this->_fentry;
	}

	// name="fstart" type="xsd:dateTime"[107] minOccurs="0" maxOccurs="1" nillable="false"
	private $_fstart = null;
	private $_hasFstart = false;
	public function setFstart($value) {
		$this->_fstart = $value;
		$this->_hasFstart = ($value !== null);
	}
	public function hasFstart() {
		return $this->_hasFstart;
	}
	public function getFstart() {
		return $this->_fstart;
	}

	// name="fexpiration" type="xsd:dateTime"[107] minOccurs="0" maxOccurs="1" nillable="false"
	private $_fexpiration = null;
	private $_hasFexpiration = false;
	public function setFexpiration($value) {
		$this->_fexpiration = $value;
		$this->_hasFexpiration = ($value !== null);
	}
	public function hasFexpiration() {
		return $this->_hasFexpiration;
	}
	public function getFexpiration() {
		return $this->_fexpiration;
	}

	// name="reference" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_reference = null;
	private $_hasReference = false;
	public function setReference($value) {
		$this->_reference = $value;
		$this->_hasReference = ($value !== null);
	}
	public function hasReference() {
		return $this->_hasReference;
	}
	public function getReference() {
		return $this->_reference;
	}

	// name="text" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_text = null;
	private $_hasText = false;
	public function setText($value) {
		$this->_text = $value;
		$this->_hasText = ($value !== null);
	}
	public function hasText() {
		return $this->_hasText;
	}
	public function getText() {
		return $this->_text;
	}

	// name="signType" type="type:signType"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_signType = null;
	private $_hasSignType = false;
	public function setSignType($value) {
		$this->_signType = $value;
		$this->_hasSignType = ($value !== null);
	}
	public function hasSignType() {
		return $this->_hasSignType;
	}
	public function getSignType() {
		return $this->_signType;
	}

	// name="application" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_application = null;
	private $_hasApplication = false;
	public function setApplication($value) {
		$this->_application = $value;
		$this->_hasApplication = ($value !== null);
	}
	public function hasApplication() {
		return $this->_hasApplication;
	}
	public function getApplication() {
		return $this->_application;
	}

	// name="importanceLevel" type="type:importanceLevel"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="true"
	private $_importanceLevel = null;
	private $_hasImportanceLevel = false;
	public function setImportanceLevel($value) {
		$this->_importanceLevel = $value;
		$this->_hasImportanceLevel = ($value !== null);
	}
	public function hasImportanceLevel() {
		return $this->_hasImportanceLevel;
	}
	public function getImportanceLevel() {
		return $this->_importanceLevel;
	}

	// name="documentList" type="type:documentList"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="true"
	private $_documentList = null;
	private $_hasDocumentList = false;
	public function setDocumentList($value) {
		$this->_documentList = $value;
		$this->_hasDocumentList = ($value !== null);
	}
	public function hasDocumentList() {
		return $this->_hasDocumentList;
	}
	public function getDocumentList() {
		return $this->_documentList;
	}

	// name="signLineList" type="type:signLineList"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="true"
	private $_signLineList = null;
	private $_hasSignLineList = false;
	public function setSignLineList($value) {
		$this->_signLineList = $value;
		$this->_hasSignLineList = ($value !== null);
	}
	public function hasSignLineList() {
		return $this->_hasSignLineList;
	}
	public function getSignLineList() {
		return $this->_signLineList;
	}

	// name="remitterList" type="type:remitterList"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="true"
	private $_remitterList = null;
	private $_hasRemitterList = false;
	public function setRemitterList($value) {
		$this->_remitterList = $value;
		$this->_hasRemitterList = ($value !== null);
	}
	public function hasRemitterList() {
		return $this->_hasRemitterList;
	}
	public function getRemitterList() {
		return $this->_remitterList;
	}

	// name="parameterList" type="type:parameterList"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="true"
	private $_parameterList = null;
	private $_hasParameterList = false;
	public function setParameterList($value) {
		$this->_parameterList = $value;
		$this->_hasParameterList = ($value !== null);
	}
	public function hasParameterList() {
		return $this->_hasParameterList;
	}
	public function getParameterList() {
		return $this->_parameterList;
	}

	// name="noticeList" type="type:noticeList"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="true"
	private $_noticeList = null;
	private $_hasNoticeList = false;
	public function setNoticeList($value) {
		$this->_noticeList = $value;
		$this->_hasNoticeList = ($value !== null);
	}
	public function hasNoticeList() {
		return $this->_hasNoticeList;
	}
	public function getNoticeList() {
		return $this->_noticeList;
	}

	// name="actionList" type="type:actionList"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="true"
	private $_actionList = null;
	private $_hasActionList = false;
	public function setActionList($value) {
		$this->_actionList = $value;
		$this->_hasActionList = ($value !== null);
	}
	public function hasActionList() {
		return $this->_hasActionList;
	}
	public function getActionList() {
		return $this->_actionList;
	}

	// name="commentList" type="type:commentList"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="true"
	private $_commentList = null;
	private $_hasCommentList = false;
	public function setCommentList($value) {
		$this->_commentList = $value;
		$this->_hasCommentList = ($value !== null);
	}
	public function hasCommentList() {
		return $this->_hasCommentList;
	}
	public function getCommentList() {
		return $this->_commentList;
	}

	// name="requestStatus" type="type:requestStatus"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_requestStatus = null;
	private $_hasRequestStatus = false;
	public function setRequestStatus($value) {
		$this->_requestStatus = $value;
		$this->_hasRequestStatus = ($value !== null);
	}
	public function hasRequestStatus() {
		return $this->_hasRequestStatus;
	}
	public function getRequestStatus() {
		return $this->_requestStatus;
	}

	// name="timestampInfo" type="type:timestampInfo"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="true"
	private $_timestampInfo = null;
	private $_hasTimestampInfo = false;
	public function setTimestampInfo($value) {
		$this->_timestampInfo = $value;
		$this->_hasTimestampInfo = ($value !== null);
	}
	public function hasTimestampInfo() {
		return $this->_hasTimestampInfo;
	}
	public function getTimestampInfo() {
		return $this->_timestampInfo;
	}


	static public function fromSoap($vData) {
		$newItem = new request();
		if (isset($vData['identifier'])) {
			$newItem->setIdentifier($vData['identifier']);
		}
		if (isset($vData['subject'])) {
			$newItem->setSubject($vData['subject']);
		}
		if (isset($vData['fentry'])) {
			$newItem->setFentry($vData['fentry']);
		}
		if (isset($vData['fstart'])) {
			$newItem->setFstart($vData['fstart']);
		}
		if (isset($vData['fexpiration'])) {
			$newItem->setFexpiration($vData['fexpiration']);
		}
		if (isset($vData['reference'])) {
			$newItem->setReference($vData['reference']);
		}
		if (isset($vData['text'])) {
			$newItem->setText($vData['text']);
		}
		if (isset($vData['signType'])) {
			$newItem->setSignType($vData['signType']);
		}
		if (isset($vData['application'])) {
			$newItem->setApplication($vData['application']);
		}
		if (isset($vData['importanceLevel'])) {
			$newClass = importanceLevel::fromSoap($vData['importanceLevel']);
			$newItem->setImportanceLevel($newClass);
		}
							if (isset($vData['documentList'])) {
			$newClass = documentList::fromSoap($vData['documentList']);
			$newItem->setDocumentList($newClass);
		}
							if (isset($vData['signLineList'])) {
			$newClass = signLineList::fromSoap($vData['signLineList']);
			$newItem->setSignLineList($newClass);
		}
							if (isset($vData['remitterList'])) {
			$newClass = remitterList::fromSoap($vData['remitterList']);
			$newItem->setRemitterList($newClass);
		}
							if (isset($vData['parameterList'])) {
			$newClass = parameterList::fromSoap($vData['parameterList']);
			$newItem->setParameterList($newClass);
		}
							if (isset($vData['noticeList'])) {
			$newClass = noticeList::fromSoap($vData['noticeList']);
			$newItem->setNoticeList($newClass);
		}
							if (isset($vData['actionList'])) {
			$newClass = CPFactionList::fromSoap($vData['actionList']);
			$newItem->setActionList($newClass);
		}
							if (isset($vData['commentList'])) {
			$newClass = commentList::fromSoap($vData['commentList']);
			$newItem->setCommentList($newClass);
		}
							if (isset($vData['requestStatus'])) {
			$newItem->setRequestStatus($vData['requestStatus']);
		}
		if (isset($vData['timestampInfo'])) {
			$newClass = timestampInfo::fromSoap($vData['timestampInfo']);
			$newItem->setTimestampInfo($newClass);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_identifier, 'identifier', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_subject, 'subject', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_fentry, 'fentry', 107, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_fstart, 'fstart', 107, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_fexpiration, 'fexpiration', 107, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_reference, 'reference', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_text, 'text', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_signType, 'signType', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_application, 'application', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_importanceLevel, 'importanceLevel', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_documentList, 'documentList', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_signLineList, 'signLineList', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_remitterList, 'remitterList', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_parameterList, 'parameterList', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_noticeList, 'noticeList', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_actionList, 'actionList', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_commentList, 'commentList', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_requestStatus, 'requestStatus', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_timestampInfo, 'timestampInfo', SOAP_ENC_OBJECT, $namespace, 0, 1);
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class document extends SoapObject {
	// name="identifier" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_identifier = null;
	private $_hasIdentifier = false;
	public function setIdentifier($value) {
		$this->_identifier = $value;
		$this->_hasIdentifier = ($value !== null);
	}
	public function hasIdentifier() {
		return $this->_hasIdentifier;
	}
	public function getIdentifier() {
		return $this->_identifier;
	}

	// name="name" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_name = null;
	private $_hasName = false;
	public function setName($value) {
		$this->_name = $value;
		$this->_hasName = ($value !== null);
	}
	public function hasName() {
		return $this->_hasName;
	}
	public function getName() {
		return $this->_name;
	}

	// name="mime" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_mime = null;
	private $_hasMime = false;
	public function setMime($value) {
		$this->_mime = $value;
		$this->_hasMime = ($value !== null);
	}
	public function hasMime() {
		return $this->_hasMime;
	}
	public function getMime() {
		return $this->_mime;
	}

	// name="documentType" type="type:documentType"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="true"
	private $_documentType = null;
	private $_hasDocumentType = false;
	public function setDocumentType($value) {
		$this->_documentType = $value;
		$this->_hasDocumentType = ($value !== null);
	}
	public function hasDocumentType() {
		return $this->_hasDocumentType;
	}
	public function getDocumentType() {
		return $this->_documentType;
	}

	// name="content" type="xsd:base64Binary"[116] minOccurs="0" maxOccurs="1" nillable="true"
	private $_content = null;
	private $_hasContent = false;
	public function setContent($value) {
		$this->_content = $value;
		$this->_hasContent = ($value !== null);
	}
	public function hasContent() {
		return $this->_hasContent;
	}
	public function getContent() {
		return $this->_content;
	}

	// name="type" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_type = null;
	private $_hasType = false;
	public function setType($value) {
		$this->_type = $value;
		$this->_hasType = ($value !== null);
	}
	public function hasType() {
		return $this->_hasType;
	}
	public function getType() {
		return $this->_type;
	}

	// name="uri" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_uri = null;
	private $_hasUri = false;
	public function setUri($value) {
		$this->_uri = $value;
		$this->_hasUri = ($value !== null);
	}
	public function hasUri() {
		return $this->_hasUri;
	}
	public function getUri() {
		return $this->_uri;
	}

	// name="sign" type="xsd:boolean"[102] minOccurs="0" maxOccurs="1" nillable="true"
	private $_sign = null;
	private $_hasSign = false;
	public function setSign($value) {
		$this->_sign = $value;
		$this->_hasSign = ($value !== null);
	}
	public function hasSign() {
		return $this->_hasSign;
	}
	public function getSign() {
		return $this->_sign;
	}

	// name="generarCSV" type="xsd:boolean"[102] minOccurs="0" maxOccurs="1" nillable="true"
	private $_generarCSV = null;
	private $_hasGenerarCSV = false;
	public function setGenerarCSV($value) {
		$this->_generarCSV = $value;
		$this->_hasGenerarCSV = ($value !== null);
	}
	public function hasGenerarCSV() {
		return $this->_hasGenerarCSV;
	}
	public function getGenerarCSV() {
		return $this->_generarCSV;
	}

	// name="firmaposicion" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_firmaposicion = null;
	private $_hasFirmaposicion = false;
	public function setFirmaposicion($value) {
		$this->_firmaposicion = $value;
		$this->_hasFirmaposicion = ($value !== null);
	}
	public function hasFirmaposicion() {
		return $this->_hasFirmaposicion;
	}
	public function getFirmaposicion() {
		return $this->_firmaposicion;
	}


	static public function fromSoap($vData) {
		$newItem = new document();
		if (isset($vData['identifier'])) {
			$newItem->setIdentifier($vData['identifier']);
		}
		if (isset($vData['name'])) {
			$newItem->setName($vData['name']);
		}
		if (isset($vData['mime'])) {
			$newItem->setMime($vData['mime']);
		}
		if (isset($vData['documentType'])) {
			$newClass = documentType::fromSoap($vData['documentType']);
			$newItem->setDocumentType($newClass);
		}
							if (isset($vData['content'])) {
			$newItem->setContent($vData['content']);
		}
		if (isset($vData['type'])) {
			$newItem->setType($vData['type']);
		}
		if (isset($vData['uri'])) {
			$newItem->setUri($vData['uri']);
		}
		if (isset($vData['sign'])) {
			$newItem->setSign($vData['sign']);
		}
		if (isset($vData['generarCSV'])) {
			$newItem->setGenerarCSV($vData['generarCSV']);
		}
		if (isset($vData['firmaposicion'])) {
			$newItem->setFirmaposicion($vData['firmaposicion']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_identifier, 'identifier', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_name, 'name', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_mime, 'mime', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_documentType, 'documentType', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_content, 'content', 116, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_type, 'type', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_uri, 'uri', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_sign, 'sign', 102, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_generarCSV, 'generarCSV', 102, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_firmaposicion, 'firmaposicion', 101, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class documentList extends SoapObject {
	// name="document" type="type:document"[COMPLEXTYPE] minOccurs="0" maxOccurs="unbounded" nillable="false"
	private $_document = array();
	private $_hasDocument = false;
	public function replaceArrayDocument($value) {
		$this->_document = $value;
		$this->_hasDocument = (isset($this->_document) && !empty($this->_document));
	}
	public function retrieveArrayDocument() {
		return $this->_document;
	}
	public function addDocument($value) {
		array_push($this->_document, $value);
		$this->_hasDocument = (isset($this->_document) && !empty($this->_document));
	}
	public function hasDocument() {
		return $this->_hasDocument;
	}
	public function getDocument($index) {
		return $this->_document[$index];
	}
	public function countDocument() {
		return count($this->_document);
	}


	static public function fromSoap($vData) {
		$newItem = new documentList();
		if (isset($vData['document']) && !empty($vData['document'])) {
			if (SoapObject::is_assoc($vData['document'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = document::fromSoap($vData['document']);
				$newItem->addDocument($newClass);
			} else {
				foreach ($vData['document'] as $oVar) {
					$newClass = document::fromSoap($oVar);
					$newItem->addDocument($newClass);
				}
			}
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_document, 'document', SOAP_ENC_OBJECT, $namespace, 0, unbounded);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class signLine extends SoapObject {
	// name="signerList" type="type:signerList"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="true"
	private $_signerList = null;
	private $_hasSignerList = false;
	public function setSignerList($value) {
		$this->_signerList = $value;
		$this->_hasSignerList = ($value !== null);
	}
	public function hasSignerList() {
		return $this->_hasSignerList;
	}
	public function getSignerList() {
		return $this->_signerList;
	}

	// name="type" type="type:signLineType"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_type = null;
	private $_hasType = false;
	public function setType($value) {
		$this->_type = $value;
		$this->_hasType = ($value !== null);
	}
	public function hasType() {
		return $this->_hasType;
	}
	public function getType() {
		return $this->_type;
	}


	static public function fromSoap($vData) {
		$newItem = new signLine();
		if (isset($vData['signerList'])) {
			$newClass = signerList::fromSoap($vData['signerList']);
			$newItem->setSignerList($newClass);
		}
							if (isset($vData['type'])) {
			$newItem->setType($vData['type']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_signerList, 'signerList', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_type, 'type', 101, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class signLineList extends SoapObject {
	// name="signLine" type="type:signLine"[COMPLEXTYPE] minOccurs="0" maxOccurs="unbounded" nillable="false"
	private $_signLine = array();
	private $_hasSignLine = false;
	public function replaceArraySignLine($value) {
		$this->_signLine = $value;
		$this->_hasSignLine = (isset($this->_signLine) && !empty($this->_signLine));
	}
	public function retrieveArraySignLine() {
		return $this->_signLine;
	}
	public function addSignLine($value) {
		array_push($this->_signLine, $value);
		$this->_hasSignLine = (isset($this->_signLine) && !empty($this->_signLine));
	}
	public function hasSignLine() {
		return $this->_hasSignLine;
	}
	public function getSignLine($index) {
		return $this->_signLine[$index];
	}
	public function countSignLine() {
		return count($this->_signLine);
	}


	static public function fromSoap($vData) {
		$newItem = new signLineList();
		if (isset($vData['signLine']) && !empty($vData['signLine'])) {
			if (SoapObject::is_assoc($vData['signLine'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = signLine::fromSoap($vData['signLine']);
				$newItem->addSignLine($newClass);
			} else {
				foreach ($vData['signLine'] as $oVar) {
					$newClass = signLine::fromSoap($oVar);
					$newItem->addSignLine($newClass);
				}
			}
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_signLine, 'signLine', SOAP_ENC_OBJECT, $namespace, 0, unbounded);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class remitterList extends SoapObject {
	// name="user" type="type:user"[COMPLEXTYPE] minOccurs="0" maxOccurs="unbounded" nillable="false"
	private $_user = array();
	private $_hasUser = false;
	public function replaceArrayUser($value) {
		$this->_user = $value;
		$this->_hasUser = (isset($this->_user) && !empty($this->_user));
	}
	public function retrieveArrayUser() {
		return $this->_user;
	}
	public function addUser($value) {
		array_push($this->_user, $value);
		$this->_hasUser = (isset($this->_user) && !empty($this->_user));
	}
	public function hasUser() {
		return $this->_hasUser;
	}
	public function getUser($index) {
		return $this->_user[$index];
	}
	public function countUser() {
		return count($this->_user);
	}


	static public function fromSoap($vData) {
		$newItem = new remitterList();
		if (isset($vData['user']) && !empty($vData['user'])) {
			if (SoapObject::is_assoc($vData['user'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = user::fromSoap($vData['user']);
				$newItem->addUser($newClass);
			} else {
				foreach ($vData['user'] as $oVar) {
					$newClass = user::fromSoap($oVar);
					$newItem->addUser($newClass);
				}
			}
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_user, 'user', SOAP_ENC_OBJECT, $namespace, 0, unbounded);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class signer extends SoapObject {
	// name="userJob" type="type:userJob"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="true"
	private $_userJob = null;
	private $_hasUserJob = false;
	public function setUserJob($value) {
		$this->_userJob = $value;
		$this->_hasUserJob = ($value !== null);
	}
	public function hasUserJob() {
		return $this->_hasUserJob;
	}
	public function getUserJob() {
		return $this->_userJob;
	}

	// name="state" type="type:state"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="true"
	private $_state = null;
	private $_hasState = false;
	public function setState($value) {
		$this->_state = $value;
		$this->_hasState = ($value !== null);
	}
	public function hasState() {
		return $this->_hasState;
	}
	public function getState() {
		return $this->_state;
	}

	// name="fstate" type="xsd:dateTime"[107] minOccurs="0" maxOccurs="1" nillable="false"
	private $_fstate = null;
	private $_hasFstate = false;
	public function setFstate($value) {
		$this->_fstate = $value;
		$this->_hasFstate = ($value !== null);
	}
	public function hasFstate() {
		return $this->_hasFstate;
	}
	public function getFstate() {
		return $this->_fstate;
	}


	static public function fromSoap($vData) {
		$newItem = new signer();
		if (isset($vData['userJob'])) {
			$newClass = userJob::fromSoap($vData['userJob']);
			$newItem->setUserJob($newClass);
		}
							if (isset($vData['state'])) {
			$newClass = state::fromSoap($vData['state']);
			$newItem->setState($newClass);
		}
							if (isset($vData['fstate'])) {
			$newItem->setFstate($vData['fstate']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_userJob, 'userJob', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_state, 'state', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_fstate, 'fstate', 107, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class signerList extends SoapObject {
	// name="signer" type="type:signer"[COMPLEXTYPE] minOccurs="0" maxOccurs="unbounded" nillable="false"
	private $_signer = array();
	private $_hasSigner = false;
	public function replaceArraySigner($value) {
		$this->_signer = $value;
		$this->_hasSigner = (isset($this->_signer) && !empty($this->_signer));
	}
	public function retrieveArraySigner() {
		return $this->_signer;
	}
	public function addSigner($value) {
		array_push($this->_signer, $value);
		$this->_hasSigner = (isset($this->_signer) && !empty($this->_signer));
	}
	public function hasSigner() {
		return $this->_hasSigner;
	}
	public function getSigner($index) {
		return $this->_signer[$index];
	}
	public function countSigner() {
		return count($this->_signer);
	}


	static public function fromSoap($vData) {
		$newItem = new signerList();
		if (isset($vData['signer']) && !empty($vData['signer'])) {
			if (SoapObject::is_assoc($vData['signer'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = signer::fromSoap($vData['signer']);
				$newItem->addSigner($newClass);
			} else {
				foreach ($vData['signer'] as $oVar) {
					$newClass = signer::fromSoap($oVar);
					$newItem->addSigner($newClass);
				}
			}
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_signer, 'signer', SOAP_ENC_OBJECT, $namespace, 0, unbounded);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class parameterList extends SoapObject {
	// name="parameter" type="type:parameter"[COMPLEXTYPE] minOccurs="0" maxOccurs="unbounded" nillable="false"
	private $_parameter = array();
	private $_hasParameter = false;
	public function replaceArrayParameter($value) {
		$this->_parameter = $value;
		$this->_hasParameter = (isset($this->_parameter) && !empty($this->_parameter));
	}
	public function retrieveArrayParameter() {
		return $this->_parameter;
	}
	public function addParameter($value) {
		array_push($this->_parameter, $value);
		$this->_hasParameter = (isset($this->_parameter) && !empty($this->_parameter));
	}
	public function hasParameter() {
		return $this->_hasParameter;
	}
	public function getParameter($index) {
		return $this->_parameter[$index];
	}
	public function countParameter() {
		return count($this->_parameter);
	}


	static public function fromSoap($vData) {
		$newItem = new parameterList();
		if (isset($vData['parameter']) && !empty($vData['parameter'])) {
			if (SoapObject::is_assoc($vData['parameter'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = parameter::fromSoap($vData['parameter']);
				$newItem->addParameter($newClass);
			} else {
				foreach ($vData['parameter'] as $oVar) {
					$newClass = parameter::fromSoap($oVar);
					$newItem->addParameter($newClass);
				}
			}
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_parameter, 'parameter', SOAP_ENC_OBJECT, $namespace, 0, unbounded);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class noticeList extends SoapObject {
	// name="state" type="type:state"[COMPLEXTYPE] minOccurs="0" maxOccurs="unbounded" nillable="false"
	private $_state = array();
	private $_hasState = false;
	public function replaceArrayState($value) {
		$this->_state = $value;
		$this->_hasState = (isset($this->_state) && !empty($this->_state));
	}
	public function retrieveArrayState() {
		return $this->_state;
	}
	public function addState($value) {
		array_push($this->_state, $value);
		$this->_hasState = (isset($this->_state) && !empty($this->_state));
	}
	public function hasState() {
		return $this->_hasState;
	}
	public function getState($index) {
		return $this->_state[$index];
	}
	public function countState() {
		return count($this->_state);
	}


	static public function fromSoap($vData) {
		$newItem = new noticeList();
		if (isset($vData['state']) && !empty($vData['state'])) {
			if (SoapObject::is_assoc($vData['state'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = state::fromSoap($vData['state']);
				$newItem->addState($newClass);
			} else {
				foreach ($vData['state'] as $oVar) {
					$newClass = state::fromSoap($oVar);
					$newItem->addState($newClass);
				}
			}
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_state, 'state', SOAP_ENC_OBJECT, $namespace, 0, unbounded);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class CPFaction extends SoapObject {
	// name="state" type="type:state"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="true"
	private $_state = null;
	private $_hasState = false;
	public function setState($value) {
		$this->_state = $value;
		$this->_hasState = ($value !== null);
	}
	public function hasState() {
		return $this->_hasState;
	}
	public function getState() {
		return $this->_state;
	}

	// name="action" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_action = null;
	private $_hasAction = false;
	public function setAction($value) {
		$this->_action = $value;
		$this->_hasAction = ($value !== null);
	}
	public function hasAction() {
		return $this->_hasAction;
	}
	public function getAction() {
		return $this->_action;
	}

	// name="type" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_type = null;
	private $_hasType = false;
	public function setType($value) {
		$this->_type = $value;
		$this->_hasType = ($value !== null);
	}
	public function hasType() {
		return $this->_hasType;
	}
	public function getType() {
		return $this->_type;
	}


	static public function fromSoap($vData) {
		$newItem = new CPFaction();
		if (isset($vData['state'])) {
			$newClass = state::fromSoap($vData['state']);
			$newItem->setState($newClass);
		}
							if (isset($vData['action'])) {
			$newItem->setAction($vData['action']);
		}
		if (isset($vData['type'])) {
			$newItem->setType($vData['type']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_state, 'state', SOAP_ENC_OBJECT, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_action, 'action', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_type, 'type', 101, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class CPFactionList extends SoapObject {
	// name="action" type="type:action"[COMPLEXTYPE] minOccurs="0" maxOccurs="unbounded" nillable="false"
	private $_action = array();
	private $_hasAction = false;
	public function replaceArrayAction($value) {
		$this->_action = $value;
		$this->_hasAction = (isset($this->_action) && !empty($this->_action));
	}
	public function retrieveArrayAction() {
		return $this->_action;
	}
	public function addAction($value) {
		array_push($this->_action, $value);
		$this->_hasAction = (isset($this->_action) && !empty($this->_action));
	}
	public function hasAction() {
		return $this->_hasAction;
	}
	public function getAction($index) {
		return $this->_action[$index];
	}
	public function countAction() {
		return count($this->_action);
	}


	static public function fromSoap($vData) {
		$newItem = new CPFactionList();
		if (isset($vData['action']) && !empty($vData['action'])) {
			if (SoapObject::is_assoc($vData['action'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = CPFaction::fromSoap($vData['action']);
				$newItem->addAction($newClass);
			} else {
				foreach ($vData['action'] as $oVar) {
					$newClass = CPFaction::fromSoap($oVar);
					$newItem->addAction($newClass);
				}
			}
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_action, 'action', SOAP_ENC_OBJECT, $namespace, 0, unbounded);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class comment extends SoapObject {
	// name="subject" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_subject = null;
	private $_hasSubject = false;
	public function setSubject($value) {
		$this->_subject = $value;
		$this->_hasSubject = ($value !== null);
	}
	public function hasSubject() {
		return $this->_hasSubject;
	}
	public function getSubject() {
		return $this->_subject;
	}

	// name="textComment" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="false"
	private $_textComment = null;
	private $_hasTextComment = false;
	public function setTextComment($value) {
		$this->_textComment = $value;
		$this->_hasTextComment = ($value !== null);
	}
	public function hasTextComment() {
		return $this->_hasTextComment;
	}
	public function getTextComment() {
		return $this->_textComment;
	}

	// name="fmodify" type="xsd:dateTime"[107] minOccurs="0" maxOccurs="1" nillable="false"
	private $_fmodify = null;
	private $_hasFmodify = false;
	public function setFmodify($value) {
		$this->_fmodify = $value;
		$this->_hasFmodify = ($value !== null);
	}
	public function hasFmodify() {
		return $this->_hasFmodify;
	}
	public function getFmodify() {
		return $this->_fmodify;
	}

	// name="user" type="type:userJob"[COMPLEXTYPE] minOccurs="0" maxOccurs="1" nillable="false"
	private $_user = null;
	private $_hasUser = false;
	public function setUser($value) {
		$this->_user = $value;
		$this->_hasUser = ($value !== null);
	}
	public function hasUser() {
		return $this->_hasUser;
	}
	public function getUser() {
		return $this->_user;
	}


	static public function fromSoap($vData) {
		$newItem = new comment();
		if (isset($vData['subject'])) {
			$newItem->setSubject($vData['subject']);
		}
		if (isset($vData['textComment'])) {
			$newItem->setTextComment($vData['textComment']);
		}
		if (isset($vData['fmodify'])) {
			$newItem->setFmodify($vData['fmodify']);
		}
		if (isset($vData['user'])) {
			$newClass = user::fromSoap($vData['user']);
			$newItem->setUser($newClass);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_subject, 'subject', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_textComment, 'textComment', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_fmodify, 'fmodify', 107, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_user, 'user', SOAP_ENC_OBJECT, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class commentList extends SoapObject {
	// name="comment" type="type:comment"[COMPLEXTYPE] minOccurs="0" maxOccurs="unbounded" nillable="false"
	private $_comment = array();
	private $_hasComment = false;
	public function replaceArrayComment($value) {
		$this->_comment = $value;
		$this->_hasComment = (isset($this->_comment) && !empty($this->_comment));
	}
	public function retrieveArrayComment() {
		return $this->_comment;
	}
	public function addComment($value) {
		array_push($this->_comment, $value);
		$this->_hasComment = (isset($this->_comment) && !empty($this->_comment));
	}
	public function hasComment() {
		return $this->_hasComment;
	}
	public function getComment($index) {
		return $this->_comment[$index];
	}
	public function countComment() {
		return count($this->_comment);
	}


	static public function fromSoap($vData) {
		$newItem = new commentList();
		if (isset($vData['comment']) && !empty($vData['comment'])) {
			if (SoapObject::is_assoc($vData['comment'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newClass = comment::fromSoap($vData['comment']);
				$newItem->addComment($newClass);
			} else {
				foreach ($vData['comment'] as $oVar) {
					$newClass = comment::fromSoap($oVar);
					$newItem->addComment($newClass);
				}
			}
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_comment, 'comment', SOAP_ENC_OBJECT, $namespace, 0, unbounded);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class authentication extends SoapObject {
	// name="userName" type="xsd:string"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_userName = null;
	private $_hasUserName = false;
	public function setUserName($value) {
		$this->_userName = $value;
		$this->_hasUserName = ($value !== null);
	}
	public function hasUserName() {
		return $this->_hasUserName;
	}
	public function getUserName() {
		return $this->_userName;
	}

	// name="password" type="xsd:string"[101] minOccurs="1" maxOccurs="1" nillable="false"
	private $_password = null;
	private $_hasPassword = false;
	public function setPassword($value) {
		$this->_password = $value;
		$this->_hasPassword = ($value !== null);
	}
	public function hasPassword() {
		return $this->_hasPassword;
	}
	public function getPassword() {
		return $this->_password;
	}


	static public function fromSoap($vData) {
		$newItem = new authentication();
		if (!isset($vData['userName'])) {
			throw new \Exception('El parametro userName es obligatorio');
		}
		if (isset($vData['userName'])) {
			$newItem->setUserName($vData['userName']);
		}
		if (!isset($vData['password'])) {
			throw new \Exception('El parametro password es obligatorio');
		}
		if (isset($vData['password'])) {
			$newItem->setPassword($vData['password']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_userName, 'userName', 101, $namespace, 1, 1);
		$this->__doChild($myLevel, $this->_password, 'password', 101, $namespace, 1, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class signature extends SoapObject {
	// name="identifier" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_identifier = null;
	private $_hasIdentifier = false;
	public function setIdentifier($value) {
		$this->_identifier = $value;
		$this->_hasIdentifier = ($value !== null);
	}
	public function hasIdentifier() {
		return $this->_hasIdentifier;
	}
	public function getIdentifier() {
		return $this->_identifier;
	}

	// name="sign" type="xsd:boolean"[102] minOccurs="0" maxOccurs="1" nillable="true"
	private $_sign = null;
	private $_hasSign = false;
	public function setSign($value) {
		$this->_sign = $value;
		$this->_hasSign = ($value !== null);
	}
	public function hasSign() {
		return $this->_hasSign;
	}
	public function getSign() {
		return $this->_sign;
	}

	// name="signFormat" type="type:signFormat"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_signFormat = null;
	private $_hasSignFormat = false;
	public function setSignFormat($value) {
		$this->_signFormat = $value;
		$this->_hasSignFormat = ($value !== null);
	}
	public function hasSignFormat() {
		return $this->_hasSignFormat;
	}
	public function getSignFormat() {
		return $this->_signFormat;
	}

	// name="csv" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_csv = null;
	private $_hasCsv = false;
	public function setCsv($value) {
		$this->_csv = $value;
		$this->_hasCsv = ($value !== null);
	}
	public function hasCsv() {
		return $this->_hasCsv;
	}
	public function getCsv() {
		return $this->_csv;
	}

	// name="csvAnulado" type="xsd:boolean"[102] minOccurs="0" maxOccurs="1" nillable="true"
	private $_csvAnulado = null;
	private $_hasCsvAnulado = false;
	public function setCsvAnulado($value) {
		$this->_csvAnulado = $value;
		$this->_hasCsvAnulado = ($value !== null);
	}
	public function hasCsvAnulado() {
		return $this->_hasCsvAnulado;
	}
	public function getCsvAnulado() {
		return $this->_csvAnulado;
	}

	// name="csvNormativa" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_csvNormativa = null;
	private $_hasCsvNormativa = false;
	public function setCsvNormativa($value) {
		$this->_csvNormativa = $value;
		$this->_hasCsvNormativa = ($value !== null);
	}
	public function hasCsvNormativa() {
		return $this->_hasCsvNormativa;
	}
	public function getCsvNormativa() {
		return $this->_csvNormativa;
	}

	// name="content" type="xsd:base64Binary"[116] minOccurs="0" maxOccurs="1" nillable="true"
	private $_content = null;
	private $_hasContent = false;
	public function setContent($value) {
		$this->_content = $value;
		$this->_hasContent = ($value !== null);
	}
	public function hasContent() {
		return $this->_hasContent;
	}
	public function getContent() {
		return $this->_content;
	}


	static public function fromSoap($vData) {
		$newItem = new signature();
		if (isset($vData['identifier'])) {
			$newItem->setIdentifier($vData['identifier']);
		}
		if (isset($vData['sign'])) {
			$newItem->setSign($vData['sign']);
		}
		if (isset($vData['signFormat'])) {
			$newItem->setSignFormat($vData['signFormat']);
		}
		if (isset($vData['csv'])) {
			$newItem->setCsv($vData['csv']);
		}
		if (isset($vData['csvAnulado'])) {
			$newItem->setCsvAnulado($vData['csvAnulado']);
		}
		if (isset($vData['csvNormativa'])) {
			$newItem->setCsvNormativa($vData['csvNormativa']);
		}
		if (isset($vData['content'])) {
			$newItem->setContent($vData['content']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_identifier, 'identifier', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_sign, 'sign', 102, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_signFormat, 'signFormat', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_csv, 'csv', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_csvAnulado, 'csvAnulado', 102, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_csvNormativa, 'csvNormativa', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_content, 'content', 116, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class signatureRef extends SoapObject {
	// name="identifier" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_identifier = null;
	private $_hasIdentifier = false;
	public function setIdentifier($value) {
		$this->_identifier = $value;
		$this->_hasIdentifier = ($value !== null);
	}
	public function hasIdentifier() {
		return $this->_hasIdentifier;
	}
	public function getIdentifier() {
		return $this->_identifier;
	}

	// name="sign" type="xsd:boolean"[102] minOccurs="0" maxOccurs="1" nillable="true"
	private $_sign = null;
	private $_hasSign = false;
	public function setSign($value) {
		$this->_sign = $value;
		$this->_hasSign = ($value !== null);
	}
	public function hasSign() {
		return $this->_hasSign;
	}
	public function getSign() {
		return $this->_sign;
	}

	// name="signFormat" type="type:signFormat"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_signFormat = null;
	private $_hasSignFormat = false;
	public function setSignFormat($value) {
		$this->_signFormat = $value;
		$this->_hasSignFormat = ($value !== null);
	}
	public function hasSignFormat() {
		return $this->_hasSignFormat;
	}
	public function getSignFormat() {
		return $this->_signFormat;
	}

	// name="csv" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_csv = null;
	private $_hasCsv = false;
	public function setCsv($value) {
		$this->_csv = $value;
		$this->_hasCsv = ($value !== null);
	}
	public function hasCsv() {
		return $this->_hasCsv;
	}
	public function getCsv() {
		return $this->_csv;
	}

	// name="csvAnulado" type="xsd:boolean"[102] minOccurs="0" maxOccurs="1" nillable="true"
	private $_csvAnulado = null;
	private $_hasCsvAnulado = false;
	public function setCsvAnulado($value) {
		$this->_csvAnulado = $value;
		$this->_hasCsvAnulado = ($value !== null);
	}
	public function hasCsvAnulado() {
		return $this->_hasCsvAnulado;
	}
	public function getCsvAnulado() {
		return $this->_csvAnulado;
	}

	// name="csvNormativa" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_csvNormativa = null;
	private $_hasCsvNormativa = false;
	public function setCsvNormativa($value) {
		$this->_csvNormativa = $value;
		$this->_hasCsvNormativa = ($value !== null);
	}
	public function hasCsvNormativa() {
		return $this->_hasCsvNormativa;
	}
	public function getCsvNormativa() {
		return $this->_csvNormativa;
	}

	// name="gde" type="xsd:string"[101] minOccurs="0" maxOccurs="1" nillable="true"
	private $_gde = null;
	private $_hasGde = false;
	public function setGde($value) {
		$this->_gde = $value;
		$this->_hasGde = ($value !== null);
	}
	public function hasGde() {
		return $this->_hasGde;
	}
	public function getGde() {
		return $this->_gde;
	}


	static public function fromSoap($vData) {
		$newItem = new signatureRef();
		if (isset($vData['identifier'])) {
			$newItem->setIdentifier($vData['identifier']);
		}
		if (isset($vData['sign'])) {
			$newItem->setSign($vData['sign']);
		}
		if (isset($vData['signFormat'])) {
			$newItem->setSignFormat($vData['signFormat']);
		}
		if (isset($vData['csv'])) {
			$newItem->setCsv($vData['csv']);
		}
		if (isset($vData['csvAnulado'])) {
			$newItem->setCsvAnulado($vData['csvAnulado']);
		}
		if (isset($vData['csvNormativa'])) {
			$newItem->setCsvNormativa($vData['csvNormativa']);
		}
		if (isset($vData['gde'])) {
			$newItem->setGde($vData['gde']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_identifier, 'identifier', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_sign, 'sign', 102, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_signFormat, 'signFormat', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_csv, 'csv', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_csvAnulado, 'csvAnulado', 102, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_csvNormativa, 'csvNormativa', 101, $namespace, 0, 1);
		$this->__doChild($myLevel, $this->_gde, 'gde', 101, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class timestampInfo extends SoapObject {
	// name="addTimestamp" type="xsd:boolean"[102] minOccurs="0" maxOccurs="1" nillable="false"
	private $_addTimestamp = null;
	private $_hasAddTimestamp = false;
	public function setAddTimestamp($value) {
		$this->_addTimestamp = $value;
		$this->_hasAddTimestamp = ($value !== null);
	}
	public function hasAddTimestamp() {
		return $this->_hasAddTimestamp;
	}
	public function getAddTimestamp() {
		return $this->_addTimestamp;
	}


	static public function fromSoap($vData) {
		$newItem = new timestampInfo();
		if (isset($vData['addTimestamp'])) {
			$newItem->setAddTimestamp($vData['addTimestamp']);
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_addTimestamp, 'addTimestamp', 102, $namespace, 0, 1);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

class stringList extends SoapObject {
	// name="str" type="xsd:string"[101] minOccurs="0" maxOccurs="unbounded" nillable="false"
	private $_str = array();
	private $_hasStr = false;
	public function replaceArrayStr($value) {
		$this->_str = $value;
		$this->_hasStr = (isset($this->_str) && !empty($this->_str));
	}
	public function retrieveArrayStr() {
		return $this->_str;
	}
	public function addStr($value) {
		array_push($this->_str, $value);
		$this->_hasStr = (isset($this->_str) && !empty($this->_str));
	}
	public function hasStr() {
		return $this->_hasStr;
	}
	public function getStr($index) {
		return $this->_str[$index];
	}
	public function countStr() {
		return count($this->_str);
	}


	static public function fromSoap($vData) {
		$newItem = new stringList();
		if (isset($vData['str']) && !empty($vData['str'])) {
			if (SoapObject::is_assoc($vData['str'])) {
				// Si es asociativo, lo probable es que nos encontremos ante un array de un solo elemento de forma que directamente se ha introducido el elemento a tratar
				$newItem->addStr($vData['str']);
			} else {
				$newItem->replaceAllStr($vData['str']);
			}
		}

		return $newItem;
	}
	public function toSoap($fieldName, $namespace) {
		$myLevel = new \ArrayObject();

		$this->__doChild($myLevel, $this->_str, 'str', 101, $namespace, 0, unbounded);

		//return $myLevel;
		return new \SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
	}
}

?>