<?php
namespace WSCOMUN\CSV;
use WSCOMUN\WSComunFClient;
use ArrayObject;
use DateTime;
use Exception;
use SoapVar;
/**
 * Librera para que aplicaciones PHP/GVHidra puedan acceder al Web Service de CSVGVA
 *
 * @package		WSClientCSV
 * @author 		David Pascual <pascual_dav@externosgva.es>
 * @version		Release: @package_version@
 * @copyright 	Copyright (C) 2015 Generalitat Valenciana.
 * @license 	http://opensource.org/licenses/gpl-2.0.php GNU Public License v2.0
 * @link 		https://gvhidra.gva.es/redmine/projects/wscomun
 */
class WSClientCSV extends WSComunFClient
{

	public function csv_encodeClaveAcceso($appID, $nif, $referenciaExterna, $firmante)
	{
		$claveAccesoWSRequest = new ArrayObject();
		$claveAccesoWSRequest->append(new SoapVar($appID, XSD_STRING, null, null,'aplicacionId'));
		$claveAccesoWSRequest->append(new SoapVar($nif, XSD_STRING, null, null,'nif'));
		$claveAccesoWSRequest->append(new SoapVar($referenciaExterna, XSD_STRING, null, null,'referenciaExterna'));
		$claveAccesoWSRequest->append(new SoapVar($firmante, XSD_STRING, null, null,'firmante'));

		return $claveAccesoWSRequest;
	}//csv_encodeClaveAcceso

	public function obtenerCodigo($appID, $nif, $referenciaExterna, $firmante,
			$generarBarCode=null, $tipoBarCode=null, $width=null, $height=null)
			//			                      $docContentB64=null, $nombreDoc=null, $pathDoc='', $vMetadatosENInull, $vMetadatosPersonalizados=null)
	{
		try
		{
			$this->__clienteOn(self::KEYCLIENTE_CSV, true);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_CSV);

			$claveAccesoWSRequest = $this->csv_encodeClaveAcceso($appID, $nif, $referenciaExterna, $firmante);

			$opcGeneracionWSRequest = new ArrayObject();
			if (!empty($generarBarCode))
				$opcGeneracionWSRequest->append(new SoapVar($generarBarCode, XSD_STRING, null, null,'generarBarCode'));
				if (!empty($tipoBarCode))
					$opcGeneracionWSRequest->append(new SoapVar($tipoBarCode, XSD_STRING, null, null,'tipoBarCode'));
					if (!empty($width))
						$opcGeneracionWSRequest->append(new SoapVar($width, XSD_STRING, null, null,'width'));
						if (!empty($height))
							$opcGeneracionWSRequest->append(new SoapVar($height, XSD_STRING, null, null,'height'));

							// Global
							$claveAcceso2WSRequest = new ArrayObject();
							$claveAcceso2WSRequest->append(new SoapVar($claveAccesoWSRequest, SOAP_ENC_OBJECT, null, null,'claveAcceso'));
							$claveAcceso2WSRequest->append(new SoapVar($opcGeneracionWSRequest, SOAP_ENC_OBJECT, null, null,'opcionesGeneracion'));

							// Realiza la solicitud
							$peticionWSRequest = new ArrayObject();
							$peticionWSRequest->append(new SoapVar($claveAcceso2WSRequest, SOAP_ENC_OBJECT,null,null,'peticion'));
							$miSoapRQ = new SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'obtenerCSVRequest', self::$NAMESPACE_CSVGVA);

							$respuesta = $clienteWS->obtenerCSV($miSoapRQ);
							//var_dump($respuesta->respuesta);die;


							// Respuesta
							$vRespuesta = array();//RABA0f8f9d62-08fc-4a8e-98e9-f23898075b37
							if (is_object($respuesta))
							{
								$vRespuesta = array
								(
										'csv' => $respuesta->respuesta->csv,
										'url' => $respuesta->respuesta->url,
								);
								if (isset($respuesta->respuesta->imagenBarCode))
									$vRespuesta['imagenBarCode'] = $respuesta->respuesta->imagenBarCode;
							}
							return($vRespuesta);
		}
		catch (Exception $e)
		{
			$this->tratarExcepcionEstandar($e, $clienteWS);
		}
	}//obtenerCodigo

	public function asociarCSV($csv, $appID, $nif, $referenciaExterna, $firmante,
			$idRepositorio, $refDoc, $hash, $fechaCaducidad = null, $vParametros = null)
	{
		try
		{
			$this->__clienteOn(self::KEYCLIENTE_CSV, true);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_CSV);


			$claveAccesoWSRequest = $this->csv_encodeClaveAcceso($appID, $nif, $referenciaExterna, $firmante);

			$infDocWSRequest = new ArrayObject();
			$infDocWSRequest->append(new SoapVar($idRepositorio, XSD_STRING, null, null,'idRepositorio'));
			$infDocWSRequest->append(new SoapVar($refDoc, XSD_STRING, null, null,'referenciaDocumento'));
			$infDocWSRequest->append(new SoapVar($hash, XSD_STRING, null, null,'hash'));
			if (!empty($fechaCaducidad))
				$infDocWSRequest->append(new SoapVar($fechaCaducidad->format(DateTime::ATOM), XSD_STRING, null, null,'fechaCaducidad'));
				if (is_array($vParametros)) {

					$parametrosVerificacion = new ArrayObject();

					foreach ($vParametros as $itemParametro) {
						$parametro = new ArrayObject();
						$parametro->append(new SoapVar($itemParametro['etiqueta'], XSD_STRING, null, null,'etiqueta'));
						$parametro->append(new SoapVar($itemParametro['ayuda'], XSD_STRING, null, null,'ayuda'));
						$parametro->append(new SoapVar($itemParametro['valor'], XSD_STRING, null, null,'valor'));

						$parametrosVerificacion->append(new SoapVar($parametro, SOAP_ENC_OBJECT, null, null,'parametro'));
					}

					$infDocWSRequest->append(new SoapVar($parametrosVerificacion, SOAP_ENC_OBJECT, null, null,'parametrosVerificacion'));
				}

				// Global
				$claveAcceso2WSRequest = new ArrayObject();
				$claveAcceso2WSRequest->append(new SoapVar($csv, XSD_STRING, null, null,'csv'));
				$claveAcceso2WSRequest->append(new SoapVar($claveAccesoWSRequest, SOAP_ENC_OBJECT, null, null,'claveAcceso'));
				$claveAcceso2WSRequest->append(new SoapVar($infDocWSRequest, SOAP_ENC_OBJECT, null, null,'informacionDocumento'));



				// Realiza la solicitud
				$peticionWSRequest = new ArrayObject();
				$peticionWSRequest->append(new SoapVar($claveAcceso2WSRequest, SOAP_ENC_OBJECT,null,null,'peticion'));
				$miSoapRQ = new SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'asociarCSVRequest', self::$NAMESPACE_CSVGVA);
				$respuesta = $clienteWS->asociarCSV($miSoapRQ);

				//var_dump($respuesta->respuesta->respuesta);die;

				// Respuesta
				$vRespuesta = array();
				if (is_object($respuesta))
				{
					$vRespuesta = array
					(
							'respuesta' => $respuesta->respuesta->respuesta
					);
				}
				return($vRespuesta);
		}
		catch (Exception $e)
		{
			$this->tratarExcepcionEstandar($e, $clienteWS);
		}
	}//asociarCSV

	public function invalidarCSV($csv, $appID, $nif, $referenciaExterna, $firmante)
	{
		try
		{
			$this->__clienteOn(self::KEYCLIENTE_CSV, true);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_CSV);


			$claveAccesoWSRequest = $this->csv_encodeClaveAcceso($appID, $nif, $referenciaExterna, $firmante);


			// Global
			$claveAcceso2WSRequest = new ArrayObject();
			$claveAcceso2WSRequest->append(new SoapVar($csv, XSD_STRING, null, null,'csv'));
			$claveAcceso2WSRequest->append(new SoapVar($claveAccesoWSRequest, SOAP_ENC_OBJECT, null, null,'claveAcceso'));



			// Realiza la solicitud
			$peticionWSRequest = new ArrayObject();
			$peticionWSRequest->append(new SoapVar($claveAcceso2WSRequest, SOAP_ENC_OBJECT,null,null,'peticion'));
			$miSoapRQ = new SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'invalidarCSVRequest', self::$NAMESPACE_CSVGVA);
			$respuesta = $clienteWS->invalidarCSV($miSoapRQ);
			//var_dump($respuesta->respuesta);die;

			// Respuesta
			$vRespuesta = array();//RABA0f8f9d62-08fc-4a8e-98e9-f23898075b37
			if (is_object($respuesta))
			{
				$vRespuesta = array
				(
						'respuesta' => $respuesta->respuesta->respuesta
				);
			}
			return($vRespuesta);
		}
		catch (Exception $e)
		{
			$this->tratarExcepcionEstandar($e, $clienteWS);
		}
	}//invalidarCSV

	public function modificarFechaCaducidadCSV($csv, $appID, $nif, $referenciaExterna, $firmante, $fechaCaducidad)
	{
		try
		{
			$this->__clienteOn(self::KEYCLIENTE_CSV, true);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_CSV);


			$claveAccesoWSRequest = $this->csv_encodeClaveAcceso($appID, $nif, $referenciaExterna, $firmante);


			// Global
			$claveAcceso2WSRequest = new ArrayObject();
			$claveAcceso2WSRequest->append(new SoapVar($csv, XSD_STRING, null, null,'csv'));
			$claveAcceso2WSRequest->append(new SoapVar($claveAccesoWSRequest, SOAP_ENC_OBJECT, null, null,'claveAcceso'));
			$claveAcceso2WSRequest->append(new SoapVar($fechaCaducidad->format(DateTime::ATOM), XSD_STRING, null, null,'fechaCaducidad'));


			// Realiza la solicitud
			$peticionWSRequest = new ArrayObject();
			$peticionWSRequest->append(new SoapVar($claveAcceso2WSRequest, SOAP_ENC_OBJECT,null,null,'peticion'));
			$miSoapRQ = new SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'modificarFechaCSVRequest', self::$NAMESPACE_CSVGVA);
			$respuesta = $clienteWS->modificarFechaCSV($miSoapRQ);
			//var_dump($respuesta->respuesta);die;


			// Respuesta
			$vRespuesta = array();//RABA0f8f9d62-08fc-4a8e-98e9-f23898075b37
			if (is_object($respuesta))
			{
				$vRespuesta = array
				(
						'respuesta' => $respuesta->respuesta->respuesta
				);
			}
			return($vRespuesta);
		}
		catch (Exception $e)
		{
			$this->tratarExcepcionEstandar($e, $clienteWS);
		}
	}//modificarFechaCaducidadCSV

}

?>