<?php
namespace WSCOMUN\GDE;
use WSCOMUN\WSComunFClient;
use ArrayObject;
use Exception;
use SoapVar;

/**
 * Librera para que aplicaciones PHP/GVHidra puedan acceder al Web Service de GDE
 *
 * @package		WSClientGDE
 * @author 		David Pascual <pascual_dav@externosgva.es>
 * @version		Release: @package_version@
 * @copyright 	Copyright (C) 2015 Generalitat Valenciana.
 * @license 	http://opensource.org/licenses/gpl-2.0.php GNU Public License v2.0
 * @link 		https://gvhidra.gva.es/redmine/projects/wscomun
 */
class WSClientGDE extends WSComunFClient
{

	/**
	 * Inserta doc segn parmetros recibidos y devuelve referencia al mismo
	 *
	 * No se requerir especificar las firmas, los metadatos del ENI o los
	 * metadatos personalizados. Esto permitir el uso por parte de aplicaciones
	 * que no requieran de intercambio de documentos ENI. Si se especifican
	 * metadatosEni y el Identificador ENI no viene informado, se generar
	 * automticamente por parte del GDE. Si no se indica el path se almacenar
	 * de forma automtica. En caso de que se indique path se establecer en
	 * el path indicado.
	 * @subpackage 	GDE
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param  	string	$docContentB64	Contenido del documento en Base64
	 * @param  	string	$nombreDoc	Nombre Doc.
	 * @param  	string	$pathDoc	Path relativo al espacio raz de la app
	 * @param  	array	$vMetadatosENI	Opcional. Array asociativo con meta informacin ENI [versionNTI|identificador|tipoDocumental|nombreFormatoorgano|fechaCaptura|estadoElaboracion|origenCiudadanoAdministracion|identificadorDocumentoOrigen]
	 * @param  	array	$vMetadatosPersonalizados	Opcional. Array asociativo. [idColeccionMetadatosPersonalizados|metadatosPersonalizados|firmas]
	 * @return	array 	Array asociativo [referenciaDocumento|nombre]
	 * @access 	public
	 */
	public function insertarDocumentoGDE($codApp, $docContentB64, $nombreDoc, $pathDoc='', $vMetadatosENI=null, $vMetadatosPersonalizados=null)
	{
		try
		{
			$this->__clienteOn(self::KEYCLIENTE_GDE, true);
			$clienteWS = $this->v_clienteWS[self::KEYCLIENTE_GDE];


			$insertarDocumentoWSRequest = new ArrayObject();
			$insertarDocumentoWSRequest->append(new SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE));

			$peticionWSRequest = new ArrayObject();
			$peticionWSRequest->append(new SoapVar($docContentB64, XSD_STRING, null, null,'contenido', self::$NAMESPACE_GDE));
			$peticionWSRequest->append(new SoapVar($nombreDoc, XSD_STRING, null, null,'nombre', self::$NAMESPACE_GDE));

			if (!empty($pathDoc))
			{
				$peticionWSRequest->append(new SoapVar($pathDoc, XSD_STRING, null, null,'path', self::$NAMESPACE_GDE));
			}

			$insertarDocumentoWSRequest->append(new SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE));
			$miSoapRQ = new SoapVar($insertarDocumentoWSRequest, SOAP_ENC_OBJECT,null,null,'insertarDocumento', self::$NAMESPACE_GDE);
			$respuesta = $clienteWS->insertarDocumento($miSoapRQ);

			//Metadatos ENI
			if (is_array($vMetadatosENI))
			{
				$objMetadatosENI =$this->array2ObjectTree($vMetadatosENI);
				$peticionWSRequest->append(new SoapVar($objMetadatosENI, SOAP_ENC_OBJECT, null, null,'metadatosENI', self::$NAMESPACE_GDE));
			}

			//Metadatos Personalizados
			if (is_array($vMetadatosPersonalizados))
			{
				$objMetadatosPersonalizados = $this->array2ObjectTree($vMetadatosPersonalizados);
				$peticionWSRequest->append(new SoapVar($objMetadatosPersonalizados, SOAP_ENC_OBJECT, null, null,'coleccionMetadatosPersonalizados', self::$NAMESPACE_GDE));
			}

			$vRespuesta = array();//RABA0f8f9d62-08fc-4a8e-98e9-f23898075b37
			if (is_object($respuesta))
			{
				$vRespuesta = array
				(
						'referenciaDocumento' =>$respuesta->respuesta->referenciaDocumento,
						'nombre' => $respuesta->respuesta->nombre
				);
			}
			return($vRespuesta);
		}
		catch (Exception $e)
		{
			if ($this->getDebugMode())
			{
				$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'."\n");
				if (is_object($clienteWS))
				{
					$this->addDebugInfo("RqH:\n ".$clienteWS->__getLastRequestHeaders());
					$this->addDebugInfo("Rq:\n ".$clienteWS->__getLastRequest());
					$this->addDebugInfo("RsH:\n ".$clienteWS->__getLastResponse());
					$this->addDebugInfo("Rs:\n ".$clienteWS->__getLastResponseHeaders());
				}
				throw $e;
			}
			else
			{
				throw $e;
			}
		}
	}//insertarDocumentoGDE



	/**
	 * Accede al doc y devuelva la informacin asocaida al msimo
	 *
	 * @subpackage 	GDE
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param  	string	$refDoc	Referencia Alfresco del Doc
	 * @param  	string	$parcial Indica que datos recuperar (1: Todo, 2: Contenido, 3: Metadatos, 4: Metadatos y Firmas)
	 * @return	array	Array asociativo [contenido (b64)|nombre|borrado|metadatosENI|metadatosPersonalizados|firmas]
	 * @access 	public
	 */
	public function obtenerDocumentoGDE($codApp, $refDoc, $parcial='1')
	{
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE, true, $opcionesClienteWS);

			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE);

			$obtenerDocumentoWSRequest = new ArrayObject();
			$obtenerDocumentoWSRequest->append(new SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE));

			$peticionWSRequest = new ArrayObject();
			$peticionWSRequest->append(new SoapVar($refDoc, XSD_STRING, null, null,'referenciaDocumento', self::$NAMESPACE_GDE));
			$peticionWSRequest->append(new SoapVar($parcial, XSD_STRING, null, null,'parcial', self::$NAMESPACE_GDE));
			$obtenerDocumentoWSRequest->append(new SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE));

			$miSoapRQ = new SoapVar($obtenerDocumentoWSRequest, SOAP_ENC_OBJECT,null,null,'obtenerDocumento', self::$NAMESPACE_GDE);
			$respuesta = $clienteWS->obtenerDocumento($miSoapRQ);

			$vRespuesta = array();//RABA0f8f9d62-08fc-4a8e-98e9-f23898075b37
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (Exception $e)
		{
			// Comprobamos si estamos ante excepcion MTOM
			$mensaje = $e->getMessage();
			$mensaje = trim(strtolower($mensaje));
			if ($mensaje == 'looks like we got no xml document')
			{
				$response = $clienteWS->__getLastResponse();
				$vRetorno = $this->tratarMTOMEstandar($response);
				return ($vRetorno);
			}
			else if ($this->getDebugMode())
			{
				$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'."\n");
				if (is_object($clienteWS))
				{
					$this->addDebugInfo("RqH:\n ".$clienteWS->__getLastRequestHeaders());
					$this->addDebugInfo("Rq:\n ".$clienteWS->__getLastRequest());
					$this->addDebugInfo("RsH:\n ".$clienteWS->__getLastResponse());
					$this->addDebugInfo("Rs:\n ".$clienteWS->__getLastResponseHeaders());
				}
				throw $e;
			}
			else
			{
				throw $e;
			}
		}
	}//obtenerDocumentoGDE


	/**
	 * Dada una referencia GDE elimina el documento del gestor documental
	 *
	 * @subpackage 	GDE
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param  	string	$refDoc	Referencia Alfresco del Doc
	 * @return	boolean	TRUE si borrado correcto, o false si no se realiza
	 * @access 	public
	 */
	public function eliminarDocumentoGDE($codApp, $refDoc)
	{
		//$this->setDebugMode(true);
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE, true, $opcionesClienteWS);

			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE);

			$obtenerDocumentoWSRequest = new ArrayObject();
			$obtenerDocumentoWSRequest->append(new SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE));

			$peticionWSRequest = new ArrayObject();
			$peticionWSRequest->append(new SoapVar($refDoc, XSD_STRING, null, null,'referenciaDocumento', self::$NAMESPACE_GDE));
			$obtenerDocumentoWSRequest->append(new SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE));

			$miSoapRQ = new SoapVar($obtenerDocumentoWSRequest, SOAP_ENC_OBJECT,null,null,'eliminarDocumento', self::$NAMESPACE_GDE);
			$respuesta = $clienteWS->eliminarDocumento($miSoapRQ);

			$vRespuesta = array();//RABA0f8f9d62-08fc-4a8e-98e9-f23898075b37
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (Exception $e)
		{
			$mensaje = $e->detail->ExcepcionWS->detalleError;
			$mensaje = trim(strtolower($mensaje));
			if (strpos($mensaje, 'ya estaba borrado')===false)
			{
				if ($this->getDebugMode())
				{
					$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'."\n");
					if (is_object($clienteWS))
					{
						$this->addDebugInfo("RqH:\n ".$clienteWS->__getLastRequestHeaders());
						$this->addDebugInfo("Rq:\n ".$clienteWS->__getLastRequest());
						$this->addDebugInfo("RsH:\n ".$clienteWS->__getLastResponse());
						$this->addDebugInfo("Rs:\n ".$clienteWS->__getLastResponseHeaders());
					}
					throw $e;
				}
			}
			else
			{
				return array('correcto'=>false);
			}
		}
	}//eliminarDocumentoGDE



	/**
	 * Dado un path relativo al espacio de aplicacin, se elimna el mismo
	 *
	 * @subpackage 	GDE
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param  	string	$path	PAth relatico al espacio de aplicacin
	 * @return	boolean	TRUE si borrado correcto, o false si no se realiza
	 * @access 	public
	 */
	public function eliminarCarpetaGDE($codApp, $path)
	{
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE, true, $opcionesClienteWS);

			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE);

			$obtenerDocumentoWSRequest = new ArrayObject();
			$obtenerDocumentoWSRequest->append(new SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE));

			$peticionWSRequest = new ArrayObject();
			$peticionWSRequest->append(new SoapVar($path, XSD_STRING, null, null,'path', self::$NAMESPACE_GDE));
			$obtenerDocumentoWSRequest->append(new SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE));

			$miSoapRQ = new SoapVar($obtenerDocumentoWSRequest, SOAP_ENC_OBJECT,null,null,'eliminarCarpeta', self::$NAMESPACE_GDE);
			$respuesta = $clienteWS->eliminarCarpeta($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (Exception $e)
		{
			if ($this->getDebugMode())
			{
				$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'."\n");
				if (is_object($clienteWS))
				{
					$this->addDebugInfo("RqH:\n ".$clienteWS->__getLastRequestHeaders());
					$this->addDebugInfo("Rq:\n ".$clienteWS->__getLastRequest());
					$this->addDebugInfo("RsH:\n ".$clienteWS->__getLastResponse());
					$this->addDebugInfo("Rs:\n ".$clienteWS->__getLastResponseHeaders());
				}
				throw $e;
			}
			else
			{
				throw $e;
			}
		}
	}//eliminarCarpetaGDE

}


?>